@@ -1,8 +1,10 @@
 from viset.caltech import Caltech101
 from viset.dataset import Viset
-import cv
+from viset.show import imshow
+from time import sleep
 
-if __name__ == '__main__':
+
+def main():
   # Create a new viset
   print 'Creating vision dataset for Caltech101 dataset'
   dbfile = Caltech101().export()
@@ -13,15 +15,18 @@ if __name__ == '__main__':
   db = Viset(dbfile)
   for (im,annotation) in db.read(n_skip=100):
     print 'Image=' + str(annotation['id_img']) + ' Category=' + annotation['category']
-    cv.ShowImage('Caltech101', cv.fromarray(im))
-    cv.WaitKey(100)
+    imshow(im)
+    sleep(0.1)
 
   for (im,annotation) in db.read(category=['airplanes','Faces'], n_skip=10):
     print 'Image=' + str(annotation['id_img']) + ' Category=' + annotation['category']
-    cv.ShowImage('Caltech101', cv.fromarray(im))
-    cv.WaitKey(1000)
+    imshow(im)
+    sleep(1)
 
   # Cleanup cached data (optional)
   print 'Deleting all cached data in "' + db.cachedir + '"'  
   db.delete()
-
+  
+if __name__ == '__main__':
+  main()
+    
