@@ -1,6 +1,6 @@
 from viset.caltech import Caltech256
 from viset.dataset import Viset
-import cv
+from viset.show import imshow
 
 if __name__ == '__main__':
   # Create a new viset
@@ -13,8 +13,8 @@ if __name__ == '__main__':
   db = Viset(dbfile)
   for (im,annotation) in db.read(n_skip=100):
     print 'Image=' + str(annotation['id_img']) + ' Category=' + annotation['category']
-    cv.ShowImage('Caltech256', cv.fromarray(im))
-    cv.WaitKey(100)
+    imshow(im)
+    sleep(0.2)
 
   # Cleanup cached data (optional)
   print 'Deleting all cached data in "' + db.cachedir + '"'  
